<?php

namespace Drupal\scenarios_contenthub\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Drupal\scenarios_contenthub\ScenariosContentHub;

/**
 * Class ScenarioBuilderController.
 */
class ScenarioBuilderController extends ControllerBase {

  /**
   * Drupal\scenarios_contenthub\ScenariosContentHub definition.
   *
   * @var \Drupal\scenarios_contenthub\ScenariosContentHub
   */
  protected $scenariosContentHub;

  /**
   * ScenarioBuilderController constructor.
   *
   * @param \Drupal\scenarios_contenthub\ScenariosContentHub $scenarios_content_hub
   */
  public function __construct(ScenariosContentHub $scenarios_content_hub) {
    $this->scenariosContentHub = $scenarios_content_hub;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('scenarios_contenthub')
    );
  }

  public function download() {
    $config = $this->config('scenarios.settings');
    $types = $config->get('types');
    foreach ($types as $key => $value) {
      if ($value == '0') {
        unset($types[$key]);
      }
    }
    $scenario = $config->get('latest');
    $filename = $scenario . '.json';
    try {
      $file = $this->scenariosContentHub->export($filename, $types);
      // Load the file uri and provide a download response.
      $uri = $file->getFileUri();
      $headers = [
        'Content-Type'     => 'application/json',
        'Content-Disposition' => 'attachment;filename="' . $filename . '"'
      ];
      return new BinaryFileResponse($uri, 200, $headers, true);
    }
    catch (\Exception $e) {
      $message = $e->getMessage();
      \Drupal::logger('scenarios_contenthub')->error($message);
      \Drupal::messenger()->addError($message);
      return ['#markup' => $this->t('Error downloading Scenario: @message', ['@message' => $message])];
    }
  }

}
