<?php

namespace Drupal\scenarios_contenthub\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\depcalc\Event\FilterDependencyCalculationFieldsEvent;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\depcalc\DependencyCalculatorEvents;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Field\FieldItemListInterface;


class FilterFields implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[DependencyCalculatorEvents::FILTER_FIELDS][] = [
      'onFilterFields',
      1001
    ];
    return $events;
  }

  /**
   * @param $string
   * @param array $args
   * @param array $options
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   */
  private function t($string, array $args = [], array $options = []) {
    return new TranslatableMarkup($string, $args, $options);
  }

  /**
   * @param \Drupal\depcalc\Event\FilterDependencyCalculationFieldsEvent $event
   */
  public function onFilterFields(FilterDependencyCalculationFieldsEvent $event) {
    $scenario_author = \Drupal::config('scenarios.settings')->get('author');
    if ($author = user_load_by_name($scenario_author)) {
      $uid = $author->id();
      $fields = [];
      foreach ($event->getFields() as $field) {
        $definition = $field->getFieldDefinition()->getItemDefinition();
        $type = $definition->getDataType();
        $settings = $definition->getSettings();
        if ($type == 'field_item:entity_reference' && $settings['target_type'] == 'user') {
          $this->setFieldValue($field, [$uid], $event->getEntity());
        }
        $fields[] = $field;
      }
      $event->setFields(...$fields);
    }
  }

  /**
   * @param \Drupal\Core\Field\FieldItemListInterface $field
   * @param array $value
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   */
  private function setFieldValue(FieldItemListInterface $field, array $value, ContentEntityInterface $entity) {
    // Only allow fields in the change list to be modified at this time.
    $name = $field->getName();
    $label = $entity->label();
    $typeId = $entity->getEntityTypeId();
    $replace = ['@name' => $name, '@label' => $label, '@type' => $typeId];
    $pre_text = 'field:@name on "@label" @type ';
    $post_text = ' in CDF export.';
    $changelist = ['revision_user', 'revision_uid', 'uid', 'content_translation_uid'];
    if (in_array($name, $changelist)) {
      try {
        $field->setValue($value);
        $message = $this->t($pre_text . 'altered' . $post_text, $replace);
        \Drupal::logger('scenarios_contenthub')->info($message);
      }
      catch (\Exception $e) {
        \Drupal::logger('scenarios_contenthub')->error($e->getMessage());
      }
    }
    else {
      $message = $this->t($pre_text . 'left unaltered' . $post_text, $replace);
      \Drupal::logger('scenarios_contenthub')->warning($message);
    }
  }

}