<?php

/**
 * @file
 * Contains \Drupal\scenarios_contenthub\Form\ScenariosImportForm.
 */
namespace Drupal\scenarios_contenthub\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\scenarios_contenthub\ScenariosContentHub;

/**
 * Implements the Scenarios Import form.
 */
class ScenariosImportForm extends FormBase {

  /**
   * Drupal\scenarios_contenthub\ScenariosContentHub definition.
   *
   * @var \Drupal\scenarios_contenthub\ScenariosContentHub
   */
  protected $scenariosContentHub;

  /**
   * ExampleForm constructor.
   *
   * @param \Drupal\scenarios_contenthub\ScenariosContentHub $scenarios_content_hub
   */
  public function __construct(ScenariosContentHub $scenarios_content_hub) {
    $this->scenariosContentHub = $scenarios_content_hub;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('scenarios_contenthub')
    );
  }

  /**
   * {@inheritdoc}.
   */
  public function getFormId() {
    return 'scenarios_import_form';
  }

  /**
   * {@inheritdoc}.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['upload_cdf'] = [
      '#type' => 'managed_file',
      '#title' => $this->t('Upload CDF json file'),
      '#upload_location' => 'public://cdf',
      '#upload_validators' => [
        'file_validate_extensions' => ['json'],
      ],
    ];
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Upload file'),
      '#button_type' => 'primary'
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_file = $form_state->getValue('upload_cdf', 0);
    if (isset($form_file[0]) && !empty($form_file[0])) {
      $file = $this->scenariosContentHub->entityTypeManager->getStorage('file')->load($form_file[0]);
      $file_info = new \stdClass();
      $file_info->uri = $file->get('uri')->value;
      $file_info->filename = $file->get('filename')->value;
      if ($this->scenariosContentHub->importCDF($file_info)) {
        \Drupal::messenger()->addMessage(t('CDF import completed.'), 'status');
      }
    }
  }

}
