<?php

namespace Drupal\scenarios_ui\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Link;

/**
 * Class ScenariosController.
 */
class ScenariosController extends ControllerBase {

  /**
   * Drupal\Core\DependencyInjection\ContainerInjectionInterface definition.
   *
   * @var \Drupal\Core\DependencyInjection\ContainerInjectionInterface
   */
  protected $scenariosHandler;


  /**
   * Drupal\Core\Entity\EntityTypeManagerInterface definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;


  /**
   * Constructs a new ScenariosController object.
   */
  public function __construct(ContainerInjectionInterface $scenarios_handler,  EntityTypeManagerInterface $entity_type_manager) {
    $this->scenariosHandler = $scenarios_handler;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('scenarios_handler'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * List current Scenario information and provides helpful links.
   *
   * @return array
   *   Returns markup
   */
  public function scenariosList() {
    $scenario = $this->config('scenarios.settings')->get('latest');
    $settings = Link::createFromRoute(t('Administer Scenarios Settings'), 'scenarios.scenarios_settings_form');
    $management = Link::createFromRoute(t('Manage Installed Scenarios'), 'scenarios_ui.scenarios_ui_form');
    $items = [
      t('Nothing is installed yet.'),
      $settings
    ];
    if ($scenario != 'none') {
      $scenario_info = scenarios_info($scenario);
      $items = [
        t('Last Installed Scenario: @name (@machine_name)', [
          '@name' => $scenario_info['label']->render(),
          '@machine_name' => $scenario]),
        $settings,
        $management
      ];
    }
    $content = [
      '#theme' => 'item_list',
      '#list_type' => 'ul',
      '#items' => $items,
      '#attributes' => ['class' => 'scenarios--list--item'],
      '#wrapper_attributes' => ['class' => 'container'],
    ];
    return $content;
  }

}
